@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdefaultexternalprograms.cpp,v 1.15.2.7 2004/05/21 17:03:21 trueg Exp $
+ * $Id: k3bdefaultexternalprograms.cpp,v 1.15.2.8 2004/07/21 10:04:57 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -845,7 +845,7 @@ bool K3bDvdformatProgram::scan( const QString& p )
   if( vp.start( KProcess::Block, KProcess::AllOutput ) ) {
     // different locales make searching for the +- char difficult
     // so we simply ignore it.
-    int pos = out.output().find( QRegExp("DVD.*RW format utility") );
+    int pos = out.output().find( QRegExp("DVD.*RW(/-RAM)? format utility") );
     if( pos < 0 )
       return false;
 
