@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevice.h,v 1.56.2.3 2004/06/09 16:36:58 trueg Exp $
+ * $Id: k3bdevice.h,v 1.56.2.4 2004/07/29 10:07:16 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -650,7 +650,7 @@ namespace K3bCdDevice
     void searchIndexTransitions( long start, long end, K3bCdDevice::Track& track ) const;
     void checkWriteModes();
     void checkForAncientWriters();
-    bool rawTocDataWithBcdValues( unsigned char* data, int dataLen ) const;
+    int rawTocDataWithBcdValues( unsigned char* data, int dataLen ) const;
 
     QString m_vendor;
     QString m_description;
